@@ -1,6 +1,6 @@
-package Pcore::Captcha v0.1.3;
+package Pcore::Captcha v0.1.4;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 has cb         => ( is => 'ro', isa => CodeRef,           required => 1 );
 has captcha    => ( is => 'ro', isa => ScalarRef,         required => 1 );
@@ -18,8 +18,6 @@ has id     => ( is => 'rwp', isa => PositiveInt, predicate => 1, clearer => 1, i
 has error  => ( is => 'rwp', isa => Str,         predicate => 1, clearer => 1, init_arg => undef );
 has result => ( is => 'rwp', isa => Str,         predicate => 1, clearer => 1, init_arg => undef );
 
-no Pcore;
-
 sub clear {
     my $self = shift;
 
